@@ -2,18 +2,19 @@ package Mojo::File;
 use Mojo::Base -strict;
 use overload '@{}' => sub { shift->to_array }, bool => sub {1}, '""' => sub { ${$_[0]} }, fallback => 1;
 
-use Carp qw(croak);
-use Cwd qw(getcwd);
-use Exporter qw(import);
-use File::Basename ();
-use File::Copy qw(copy move);
-use File::Find qw(find);
-use File::Path ();
+use Carp                  qw(croak);
+use Cwd                   qw(getcwd);
+use Exporter              qw(import);
+use File::Basename        ();
+use File::Copy            qw(copy move);
+use File::Find            qw(find);
+use File::Path            ();
 use File::Spec::Functions qw(abs2rel canonpath catfile file_name_is_absolute rel2abs splitdir);
-use File::stat ();
-use File::Temp ();
-use IO::File   ();
+use File::stat            ();
+use File::Temp            ();
+use IO::File              ();
 use Mojo::Collection;
+use Mojo::Util qw(decode deprecated encode);
 
 our @EXPORT_OK = ('curfile', 'path', 'tempdir', 'tempfile');
 
@@ -37,6 +38,14 @@ sub curfile { __PACKAGE__->new(Cwd::realpath((caller)[1])) }
 
 sub dirname { $_[0]->new(scalar File::Basename::dirname ${$_[0]}) }
 
+sub download {
+  my ($self, $url, $options) = (shift, shift, shift // {});
+  my $ua = $options->{ua}
+    || do { require Mojo::UserAgent; Mojo::UserAgent->new(max_redirects => 10, max_response_size => 0) };
+  my $tx = _download_error($ua->transactor->download($ua->head($url => $options->{headers} // {}), $$self));
+  return $tx ? !!_download_error($ua->start($tx)) : 1;
+}
+
 sub extname { shift->basename =~ /.+\.([^.]+)$/ ? $1 : '' }
 
 sub is_abs { file_name_is_absolute ${shift()} }
@@ -127,23 +136,30 @@ sub sibling {
 }
 
 sub slurp {
-  my $self = shift;
+  my ($self, $encoding) = @_;
 
   CORE::open my $file, '<', $$self or croak qq{Can't open file "$$self": $!};
   my $ret = my $content = '';
   while ($ret = $file->sysread(my $buffer, 131072, 0)) { $content .= $buffer }
   croak qq{Can't read from file "$$self": $!} unless defined $ret;
 
-  return $content;
+  return $encoding ? decode($encoding, $content) : $content;
 }
 
-sub spurt {
-  my ($self, $content) = (shift, join '', @_);
+sub spew {
+  my ($self, $content, $encoding) = @_;
+  $content = encode($encoding, $content) if $encoding;
   CORE::open my $file, '>', $$self or croak qq{Can't open file "$$self": $!};
   ($file->syswrite($content) // -1) == length $content or croak qq{Can't write to file "$$self": $!};
   return $self;
 }
 
+# DEPRECATED!
+sub spurt {
+  deprecated 'Mojo::File::spurt is deprecated in favor of Mojo::File::spew';
+  shift->spew(join '', @_);
+}
+
 sub stat { File::stat::stat(${shift()}) }
 
 sub tap { shift->Mojo::Base::tap(@_) }
@@ -169,6 +185,15 @@ sub touch {
 
 sub with_roles { shift->Mojo::Base::with_roles(@_) }
 
+sub _download_error {
+  my $tx = shift;
+
+  return $tx unless my $err = $tx->error;
+  return undef if $err->{message} eq 'Download complete' || $err->{message} eq 'Download incomplete';
+  croak "$err->{code} response: $err->{message}" if $err->{code};
+  croak "Download error: $err->{message}";
+}
+
 1;
 
 =encoding utf8
@@ -192,7 +217,7 @@ Mojo::File - File system paths
   # Use the alternative constructor
   use Mojo::File qw(path);
   my $path = path('/tmp/foo/bar')->make_path;
-  $path->child('test.txt')->spurt('Hello Mojo!');
+  $path->child('test.txt')->spew('Hello Mojo!');
 
 =head1 DESCRIPTION
 
@@ -293,11 +318,21 @@ Return all but the last level of the path with L<File::Basename> as a L<Mojo::Fi
   # "/home/sri" (on UNIX)
   path('/home/sri/.vimrc')->dirname;
 
+=head2 download
+
+  my $bool = $path->download('https://example.com/test.tar.gz');
+  my $bool = $path->download('https://example.com/test.tar.gz', {headers => {Accept => '*/*'}});
+  my $bool = $path->download('https://example.com/test.tar.gz', {ua => Mojo::UserAgent->new});
+
+Download file from URL, returns true once the file has been downloaded completely. Incomplete downloads are resumed.
+Follows C<10> redirects by default and does not limit the size of the response, which will be streamed memory
+efficiently. Note that this method is B<EXPERIMENTAL> and might change without warning!
+
 =head2 extname
 
   my $ext = $path->extname;
 
-Return file extension of the path. Note that this method is B<EXPERIMENTAL> and might change without warning!
+Return file extension of the path.
 
   # "js"
   path('/home/sri/test.js')->extname;
@@ -471,15 +506,17 @@ Return a new L<Mojo::File> object relative to the directory part of the path.
 =head2 slurp
 
   my $bytes = $path->slurp;
+  my $chars = $path->slurp('UTF-8');
 
-Read all data at once from the file.
+Read all data at once from the file. If an encoding is provided, an attempt will be made to decode the content.
 
-=head2 spurt
+=head2 spew
 
-  $path = $path->spurt($bytes);
-  $path = $path->spurt(@chunks_of_bytes);
+  $path = $path->spew($bytes);
+  $path = $path->spew($chars, 'UTF-8');
 
-Write all data at once to the file.
+Write all data at once to the file. If an encoding is provided, an attempt to encode the content will be made prior to
+writing.
 
 =head2 stat
 
