@@ -41,8 +41,10 @@ EOF
 
   # Check latest version on CPAN
   my $latest = eval {
-    $self->app->ua->max_redirects(10)->tap(sub { $_->proxy->detect })
-      ->get('fastapi.metacpan.org/v1/release/Mojolicious')->result->json->{version};
+    $self->app->ua->max_redirects(10)
+      ->tap(sub { $_->proxy->detect })
+      ->get('fastapi.metacpan.org/v1/release/Mojolicious')
+      ->result->json->{version};
   } or return;
 
   my $msg = 'This version is up to date, have fun!';
