@@ -11,6 +11,8 @@ use Mojo::Util;
 use Mojolicious::Routes::Match;
 use Scalar::Util ();
 
+my $ABSOLUTE = qr!^(?:[^:/?#]+:|//|#)!;
+
 has [qw(app tx)] => undef, weak => 1;
 has match => sub { Mojolicious::Routes::Match->new(root => shift->app->routes) };
 
@@ -47,8 +49,41 @@ sub cookie {
   return $cookie->value;
 }
 
+sub encrypted_cookie {
+  my ($self, $name, $value, $options) = @_;
+
+  # Request cookie
+  return $self->every_encrypted_cookie($name)->[-1] unless defined $value;
+
+  # Response cookie
+  my $app     = $self->app;
+  my $secret  = $app->secrets->[0];
+  my $moniker = $app->moniker;
+  return $self->cookie($name, Mojo::Util::encrypt_cookie($value, $secret, $moniker), $options);
+}
+
 sub every_cookie { [map { $_->value } @{shift->req->every_cookie(shift)}] }
 
+sub every_encrypted_cookie {
+  my ($self, $name) = @_;
+
+  my $app     = $self->app;
+  my $secrets = $app->secrets;
+  my $moniker = $app->moniker;
+  my @results;
+  for my $value (@{$self->every_cookie($name)}) {
+    my $decrypted;
+    for my $secret (@$secrets) {
+      last if defined($decrypted = Mojo::Util::decrypt_cookie($value, $secret, $moniker));
+    }
+    if (defined $decrypted) { push @results, $decrypted }
+
+    else { $self->helpers->log->trace(qq{Cookie "$name" is not encrypted}) }
+  }
+
+  return \@results;
+}
+
 sub every_param {
   my ($self, $name) = @_;
 
@@ -239,7 +274,7 @@ sub url_for {
 
   # Absolute URL
   return $target                 if Scalar::Util::blessed $target && $target->isa('Mojo::URL');
-  return Mojo::URL->new($target) if $target =~ m!^(?:[^:/?#]+:|//|#)!;
+  return Mojo::URL->new($target) if $target =~ $ABSOLUTE;
 
   # Base
   my $url  = Mojo::URL->new;
@@ -274,12 +309,12 @@ sub url_for {
 
 sub url_for_asset {
   my ($self, $asset) = @_;
-  return $self->url_for($self->app->static->asset_path($asset));
+  return $self->url_for($asset =~ $ABSOLUTE ? $asset : $self->app->static->asset_path($asset));
 }
 
 sub url_for_file {
   my ($self, $file) = @_;
-  return $self->url_for($self->app->static->file_path($file));
+  return $self->url_for($file =~ $ABSOLUTE ? $file : $self->app->static->file_path($file));
 }
 
 sub write {
@@ -294,6 +329,12 @@ sub write_chunk {
   return $self->rendered;
 }
 
+sub write_sse {
+  my ($self, $event, $cb) = @_;
+  $self->res->content->write_sse($event, $cb ? sub { shift; $self->$cb(@_) } : ());
+  return $self->rendered;
+}
+
 1;
 
 =encoding utf8
@@ -397,6 +438,17 @@ you want to access more than just the last one, you can use L</"every_cookie">.
   # Create secure response cookie
   $c->cookie(secret => 'I <3 Mojolicious', {secure => 1, httponly => 1});
 
+=head2 encrypted_cookie
+
+  my $value = $c->encrypted_cookie('foo');
+  $c        = $c->encrypted_cookie(foo => 'bar');
+  $c        = $c->encrypted_cookie(foo => 'bar', {path => '/'});
+
+Access encrypted request cookie values and create new encrypted response cookies. If there are multiple values sharing
+the same name, and you want to access more than just the last one, you can use L</"every_encrypted_cookie">. Cookies
+are encrypted with ChaCha20-Poly1305, to prevent tampering, and the ones failing decryption will be automatically
+discarded. Note that this method is B<EXPERIMENTAL> and might change without warning!
+
 =head2 every_cookie
 
   my $values = $c->every_cookie('foo');
@@ -406,6 +458,16 @@ Similar to L</"cookie">, but returns all request cookie values sharing the same
   $ Get first cookie value
   my $first = $c->every_cookie('foo')->[0];
 
+=head2 every_encrypted_cookie
+
+  my $values = $c->every_encrypted_cookie('foo');
+
+Similar to L</"encrypted_cookie">, but returns all encrypted request cookie values sharing the same name as an array
+reference. Note that this method is B<EXPERIMENTAL> and might change without warning!
+
+  # Get first encrypted cookie value
+  my $first = $c->every_encrypted_cookie('foo')->[0];
+
 =head2 every_param
 
   my $values = $c->every_param('foo');
@@ -864,6 +926,27 @@ You can call L</"finish"> or write an empty chunk of data at any time to end the
   o!
   0
 
+=head2 write_sse
+
+  $c = $c->write_sse;
+  $c = $c->write_sse($event);
+  $c = $c->write_sse($event => sub ($c) {...});
+
+Write Server-Sent Event (SSE) non-blocking, the optional drain callback will be executed once all data has been
+written. Calling this method without an event will finalize the response headers and allow for events to be written
+later. Note that this method is B<EXPERIMENTAL> and might change without warning!
+
+  # Send event with default "message" type
+  $c->write_sse({text => 'Hello World!'});
+
+  # You can send comments in regular intervals to keep the connection alive
+  $c->write_sse({comment => 'Keep connection alive!'});
+
+  # Make sure previous event has been written before continuing (id and type are optional)
+  $c->write_sse({id => 23, type => 'greeting', text => 'Hello World!'} => sub ($c) {
+    $c->write_sse({id => 24, type => 'farewell', text => 'Goodbye World!'} => sub ($c) { $c->finish });
+  });
+
 =head1 HELPERS
 
 In addition to the L</"ATTRIBUTES"> and L</"METHODS"> above you can also call helpers provided by L</"app"> on
